@@ -1,10 +1,10 @@
 # -*- mode: cperl; coding: latin-2 -*-
 
 #
-# $Id: Kwalify.pm,v 1.19 2007/03/04 10:43:56 eserte Exp $
+# $Id: Kwalify.pm,v 1.21 2008/06/18 21:40:38 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 2006,2007 Slaven Rezic. All rights reserved.
+# Copyright (C) 2006,2007,2008 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -20,8 +20,8 @@ use base qw(Exporter);
 use vars qw(@EXPORT_OK $VERSION);
 @EXPORT_OK = qw(validate);
 
-$VERSION = '1.16';
-# sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '1.17';
+# sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {
     if ($] < 5.006) {
@@ -436,7 +436,7 @@ Typically used together with YAML or JSON:
 
 Kwalify is a Perl implementation for validating data structures
 against the Kwalify schema. For a schema definition, see
-L<http://www.kuwata-lab.com/kwalify/users-guide.01.html>.
+L<http://www.kuwata-lab.com/kwalify/ruby/users-guide.01.html>.
 
 =head2 validate($schema_data, $data)
 
@@ -451,7 +451,7 @@ Slaven Rezi, E<lt>srezic@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Slaven Rezi
+Copyright (C) 2006,2007,2008 by Slaven Rezi
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
